@@ -4,7 +4,7 @@ use warnings;
 use strict;
 use utf8;
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 use Acme::CPANAuthors::Register (
     AUDREYT   => "唐鳳",
@@ -13,14 +13,15 @@ use Acme::CPANAuthors::Register (
     CLSUNG    => "宋政隆",
     CORNELIUS => "林佑安",
     DRBEAN    => "高來圭",
-    GUGOD     => "劉康民",
     GSLIN     => "林嘉軒",
+    GUGOD     => "劉康民",
     HCCHIEN   => "簡信昌",
     IJLIAO    => "廖英傑",
     IMACAT    => "依瑪貓",
     KCWU      => "吳光哲",
-    KENWU     => "莉洛",
     KENSHAN   => "單中杰",
+    KENWU     => "莉洛",
+    LEEYM     => "李彥明",
     LUKHNOS   => "劉燈",
     MINDOS    => "鄭智中",
     PENK      => "陳品勳",
@@ -28,7 +29,6 @@ use Acme::CPANAuthors::Register (
     SNOWFLY   => "飄然似雪",
     VICTOR    => "謝毓庭",
     XERN      => "林永忠",
-    YMLEE     => "李彥明",
     YRCHEN    => "陳禹任",
 );
 
